/*

  $Id: gsm-filetypes.h,v 1.23 2007/05/04 19:41:34 pkot Exp $

  G N O K I I

  A Linux/Unix toolset and driver for the mobile phones.

  This file is part of gnokii.

  Gnokii is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  Gnokii is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with gnokii; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

  Copyright (C) 1999-2000 Hugh Blemings & Pavel Jank ml.
  Copyright (C) 2000      Marcin Wiacek, Chris Kemp
  Copyright (C) 2001-2003 Pawel Kot, BORBELY Zoltan
  Copyright (C) 2002      Markus Plail
  Copyright (C) 2003      Tomi Ollila

  Functions to read and write common file types.

*/

#ifndef _gnokii_gsm_filetypes_h
#define _gnokii_gsm_filetypes_h

/* Defines the character that separates fields in rtttl files. */
#define RTTTL_SEP ":"

#endif /* _gnokii_gsm_filetypes_h */
